#### .gitignore
> git ignore file
> created from the template at https://github.com/github/gitignore

#### LICENSE
> **Custom license**, software developed in-house may choose to adopt a custom license specifically tailored to meet ACC/A29 needs; the licenses can include specific terms and conditions related to ownership, usage, distribution, and modifications of the software.
> **Open source software licenses**, GNU General Public License (GPL) or the Apache License are commonly used by the DoD their in-house developed software
> "Copyright protection … is not available for any work of the United States Government, but the United States is not precluded from receiving and holding copyrights transferred to it by assignment, bequest, or otherwise."

> 17 USC § 105 at https://www.copyright.gov/title17/92chap1.html#105
> Clarifying Guidance Regarding Open Source Software (OSS) at https://dodcio.defense.gov/portals/0/documents/foss/2009oss.pdf
